//
//  NSURL+BEPathUtilities.h
//  Renamer
//
//  Created by Philipp on 10/2/12.
//  Copyright (c) 2012 Philipp Mayerhofer. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface NSURL (BEPathUtilities)

/**
 * Initializes and returns a newly created NSURL object with the root path
 */
+(NSURL *) rootFileURL;

/**
 * Returns whether the receiver is a sub path of the given file URL.
 *
 * @param anURL The file URL to be compared to the receiver
 *
 * @return YES if the receiver is a file URL whose path is a sub path of anURL, NO otherwise.
 *
 * Note that this method returns NO if the receiver and `anURL` have the same path.
 */
-(BOOL) isFileURLAndSubpathOfFileURL:(NSURL *)anURL;

/**
 * Returns a Boolean value that indicates whether a given URL is equal to the receiver.
 *
 * This differs from isEqual: in that it makes sure file URLs are treated as equals when their paths differ slightly but point to the same file object.
 */
-(BOOL)isEqualToURL:(NSURL *)anURL;

@end
